/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef D22_AUTOCONFIG_H
#define D22_AUTOCONFIG_H

#include <Controller.h>
#include <cameo/cameo.h>
#include <controllers/lss/d22/D22Settings.h>
#include <controllers/common/utilities/CountSpy.h>
#include <drivers/utilities/null/NullDriver.h>

namespace d22 {

class AutoConfig : public ExperimentController,
						public controller::Start {

public:
	//! Type of controller
	static const std::string TYPE;

	AutoConfig(const std::string& name);
	AutoConfig(const AutoConfig& controller);
	virtual ~AutoConfig();

	virtual void postConfiguration();

	virtual void start();

	Property<std::string> serverEndpoint;
	Property<bool> initialized;

	Property<float64> distance;
	Property<float64> wavelength;
	Property<float64> collimation;
	Property<std::string> scatterModelType;
	Property<std::string> type;
	Property<float64> sampleRadius;

private:
	bool initApplication();

	static const std::string REMOTE_APPLICATION;
	static const std::string RESPONDER;

	std::unique_ptr<cameo::Server> m_server;
	std::unique_ptr<cameo::application::Instance> m_remoteApplication;

	ControllerPtr<D22Settings> m_d22settings;
	DriverPtr<driver::NullDriver> m_driver;
	utilities::CountSpy* m_countSpy;
};

}

#endif
