/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

/*!
 * \brief PN1Coincidence Detector Element class
 * \author J. Locatelli
 * \date 10-01-2010
 */

#ifndef PN1COINCIDENCEDETECTORELEMENT_H
#define PN1COINCIDENCEDETECTORELEMENT_H

#include "controllers/common/acquisition/detector/DetectorElement.h"
#include "drivers/ioxos/mpda_dpp/MpdaDPPDriver.h"

namespace npp {

/*!
 * \class PN1CoincidenceDetectorElement
 * \brief PN1CoincidenceDetectorElement class
 *
 * \par
 *	This class overload. DetectorElement class. It creates a new data array for plot window.
 *	The data have to be rotated for the plot.
 */
class PN1CoincidenceDetectorElement: public acquisition::DetectorElement {

public:

	//! Type of controller
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the experiment controller
	 */
	PN1CoincidenceDetectorElement(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~PN1CoincidenceDetectorElement();

	/*!
	 * \brief Method called before changing the property value
	 *
	 * This method is called after setting configuration during the creation of controller.
	 */
	virtual void postConfiguration();

private:

	DriverPtr<mpda_dpp::MpdaDPPDriver> m_Driver; //! Pointer on histo data

	void updateData();

};

}
#endif
