/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENPKSDRIVER_H
#define CAENPKSDRIVER_H

#include <Driver.h>
#include "drivers/global/Vme.h"

namespace caen_pks {

/*!
 * \class CAENPksDriver
 * \brief Main class for the CAENPksDriver device driver
 *
 * \par
 * Class for CAENPksDriver driver. Implements DeviceDriver methods.
 * \par
 * The CAENPksDriver device manages the global functionality of the CAEN V785 VME Peak Sensing ADCr.
 */

class CAENPksDriver : public driver::Vme {

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	CAENPksDriver(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CAENPksDriver();

	/*!
	 * \brief Method called for executing a command
	 *
	 * \param[in] command the command to apply on the controller
	 */
	virtual void execute(const std::string& aCommand);

	// Global properties
	Property<int32> nbChannels;
    Property<int32> model;
    Property<int32> firmware;
    Property<std::string> modelName;

	// Channels properties
	DynamicProperty<int32> triggerThreshold;		// thr - range 0:16383
	DynamicProperty<int32> channelActive;
	DynamicProperty<std::string> channelActiveStr;

	// Commands
	static const std::string WRITE_PARAMETERS_COMMAND;
	static const std::string RESET_COMMAND;
	static const std::string CLEAR_COMMAND;

private:

	void refreshNbChannelsProperty(int32 aValue) throw (CannotSetValue);
	void refreshChannelActiveProperty(int32 index, int32 aValue) throw (CannotSetValue);
};

}
#endif //CAENPHADRIVER_H
