/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENSY2527BOARDDRIVER_H
#define CAENSY2527BOARDDRIVER_H

#include "controllers/common/detector_hv/DetectorHVCommon.h"

namespace caen_sy2527 {

/**
 * Global implementation of the VME power supply CAENV65xx Channel.
 */
class CAENSy2527BoardDriver : public detector_hv::DetectorHVCommon {

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	CAENSy2527BoardDriver(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CAENSy2527BoardDriver();

	/**
	 * Execute the command on the device.
	 * The DeviceActionDriver class gives the command to the DeviceDriver.
	 * Each type of device have to interpret its command and call
	 * the write method.
	 *
	 * @param the command to apply on the device
	 */
	virtual void execute(const std::string& aCommand);

//	virtual void refreshPowerProperty(int32 index, std::string aValue) throw (CannotSetValue);

private:

	// Local commands
	static const std::string SWITCH_ON_COMMAND;
	static const std::string SWITCH_OFF_COMMAND;

};

}

#endif //CAENSY2527BOARDDRIVER_H
