/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "PerfectPslDriver.h"

#include <stdlib.h>

#include "PslDef.h"
#include "PslDriver.h"

namespace psl {

/*
 * Constructor
 */
PerfectPslDriver::PerfectPslDriver(PslDriver* owner) :
				PslState(owner) {
	/* Empty */
}

/*
 * Destructor
 */
PerfectPslDriver::~PerfectPslDriver() {
	/* Empty */
}

void PerfectPslDriver::init() {
}

/*
 * clearvme/daugther/Psl
 */
void PerfectPslDriver::clear() {
	// Read command
	owner()->time = 0;
	owner()->counts = 0;
	owner()->counts2 = 0;
	owner()->counts3 = 0;
}

/*
 * writeParam
 */
void PerfectPslDriver::writeParam() {
}

/*
 * synchroniseRead
 */
void PerfectPslDriver::synchroniseRead() {
	read();
	owner()->m_SynchroniseReadTerminated = true;
}

/*
 * read
 */
void PerfectPslDriver::read() {
	// Read command
	int32 size = owner()->dataSize();

	int32 *tab = owner()->data();

	int32 sum = 0;
	//  if (m_FirstRead) {
	//    for (uint32 i=0;i<size;i++) {
	//      tab[i] = i + 1;
	//      sum = sum + tab[i];
	//    }
	//    m_FirstRead = false;
	//  } else {
	//    for (uint32 i=0;i<size;i++) {
	//      tab[i] = tab[i] + 1;
	//      sum = sum + tab[i];
	//    }
	//  }
	for (int32 i = 0; i < size; i++) {
		tab[i] = i;
		sum = sum + tab[i];
	}
	owner()->sum = sum;
	owner()->data.sendEvent();
}

/*
 * pause 
 */
void PerfectPslDriver::pause() {
}

/*
 * continue 
 */
void PerfectPslDriver::resume() {
}

/*
 * start
 */
void PerfectPslDriver::start() {
	owner()->time = owner()->time.setpoint();
}

/*
 * stop
 */
void PerfectPslDriver::stop() {
}

/*
 * readStatus
 */
void PerfectPslDriver::readStatus() {
	owner()->startActivated = false;
	// Status command
	owner()->computeGateStatus(psl::READOUT_COMPLETE);
	owner()->computeAcquisitionStatus(0);
	owner()->computeDetectorStatus(0);
	if (owner()->m_SynchroniseReadActivated == true) {
		if (owner()->m_SynchroniseReadTerminated == true) {
			owner()->m_SynchroniseReadActivated = false;
			owner()->m_SynchroniseReadTerminated = false;
			owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
		}
	} else {
		owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
	}
}

/*
 * readInfos
 */
void PerfectPslDriver::readInfos() {
}

}
